@@ -16,9 +16,10 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 import re
+from collections.abc import Iterable
 from enum import Enum
 from os.path import exists
-from typing import Any, Dict, FrozenSet, Iterable, Optional, Set, Type, Union
+from typing import Any, Optional, Union
 from warnings import warn
 
 # See https://github.com/package-url/packageurl-python/issues/65
@@ -43,11 +44,11 @@ from ..schema.schema import (
     SchemaVersion1Dot4,
     SchemaVersion1Dot5,
     SchemaVersion1Dot6,
+    SchemaVersion1Dot7,
 )
 from ..serialization import PackageUrl as PackageUrlSH
 from . import (
     AttachedText,
-    Copyright,
     ExternalReference,
     HashAlgorithm,
     HashType,
@@ -57,6 +58,7 @@ from . import (
     _HashTypeRepositorySerializationHelper,
 )
 from .bom_ref import BomRef
+from .component_evidence import ComponentEvidence, _ComponentEvidenceSerializationHelper
 from .contact import OrganizationalContact, OrganizationalEntity
 from .crypto import CryptoProperties
 from .dependency import Dependable
@@ -65,13 +67,13 @@ from .license import License, LicenseRepository, _LicenseRepositorySerialization
 from .release_note import ReleaseNotes
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Commit:
     """
     Our internal representation of the `commitType` complex type.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_commitType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_commitType
     """
 
     def __init__(
@@ -190,115 +192,13 @@ class Commit:
         return f'<Commit uid={self.uid}, url={self.url}, message={self.message}>'
 
 
-@serializable.serializable_class
-class ComponentEvidence:
-    """
-    Our internal representation of the `componentEvidenceType` complex type.
-
-    Provides the ability to document evidence collected through various forms of extraction or analysis.
-
-    .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_componentEvidenceType
-    """
-
-    def __init__(
-        self, *,
-        licenses: Optional[Iterable[License]] = None,
-        copyright: Optional[Iterable[Copyright]] = None,
-    ) -> None:
-        self.licenses = licenses or []  # type:ignore[assignment]
-        self.copyright = copyright or []  # type:ignore[assignment]
-
-    # @property
-    # ...
-    # @serializable.view(SchemaVersion1Dot5)
-    # @serializable.xml_sequence(1)
-    # def identity(self) -> ...:
-    #    ... # TODO since CDX1.5
-    #
-    # @identity.setter
-    # def identity(self, ...) -> None:
-    #    ... # TODO since CDX1.5
-
-    # @property
-    # ...
-    # @serializable.view(SchemaVersion1Dot5)
-    # @serializable.xml_sequence(2)
-    # def occurrences(self) -> ...:
-    #    ... # TODO since CDX1.5
-    #
-    # @occurrences.setter
-    # def occurrences(self, ...) -> None:
-    #    ... # TODO since CDX1.5
-
-    # @property
-    # ...
-    # @serializable.view(SchemaVersion1Dot5)
-    # @serializable.xml_sequence(3)
-    # def callstack(self) -> ...:
-    #    ... # TODO since CDX1.5
-    #
-    # @callstack.setter
-    # def callstack(self, ...) -> None:
-    #    ... # TODO since CDX1.5
-
-    @property
-    @serializable.type_mapping(_LicenseRepositorySerializationHelper)
-    @serializable.xml_sequence(4)
-    def licenses(self) -> LicenseRepository:
-        """
-        Optional list of licenses obtained during analysis.
-
-        Returns:
-            Set of `LicenseChoice`
-        """
-        return self._licenses
-
-    @licenses.setter
-    def licenses(self, licenses: Iterable[License]) -> None:
-        self._licenses = LicenseRepository(licenses)
-
-    @property
-    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'text')
-    @serializable.xml_sequence(5)
-    def copyright(self) -> 'SortedSet[Copyright]':
-        """
-        Optional list of copyright statements.
-
-        Returns:
-             Set of `Copyright`
-        """
-        return self._copyright
-
-    @copyright.setter
-    def copyright(self, copyright: Iterable[Copyright]) -> None:
-        self._copyright = SortedSet(copyright)
-
-    def __comparable_tuple(self) -> _ComparableTuple:
-        return _ComparableTuple((
-            _ComparableTuple(self.licenses),
-            _ComparableTuple(self.copyright),
-        ))
-
-    def __eq__(self, other: object) -> bool:
-        if isinstance(other, ComponentEvidence):
-            return self.__comparable_tuple() == other.__comparable_tuple()
-        return False
-
-    def __hash__(self) -> int:
-        return hash(self.__comparable_tuple())
-
-    def __repr__(self) -> str:
-        return f'<ComponentEvidence id={id(self)}>'
-
-
 @serializable.serializable_enum
 class ComponentScope(str, Enum):
     """
     Enum object that defines the permissable 'scopes' for a Component according to the CycloneDX schema.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_scope
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_scope
     """
     # see `_ComponentScopeSerializationHelper.__CASES` for view/case map
     REQUIRED = 'required'
@@ -309,7 +209,7 @@ class ComponentScope(str, Enum):
 class _ComponentScopeSerializationHelper(serializable.helpers.BaseHelper):
     """  THIS CLASS IS NON-PUBLIC API  """
 
-    __CASES: Dict[Type[serializable.ViewType], FrozenSet[ComponentScope]] = dict()
+    __CASES: dict[type[serializable.ViewType], frozenset[ComponentScope]] = dict()
     __CASES[SchemaVersion1Dot0] = frozenset({
         ComponentScope.REQUIRED,
         ComponentScope.OPTIONAL,
@@ -322,23 +222,24 @@ class _ComponentScopeSerializationHelper(serializable.helpers.BaseHelper):
     __CASES[SchemaVersion1Dot4] = __CASES[SchemaVersion1Dot3]
     __CASES[SchemaVersion1Dot5] = __CASES[SchemaVersion1Dot4]
     __CASES[SchemaVersion1Dot6] = __CASES[SchemaVersion1Dot5]
+    __CASES[SchemaVersion1Dot7] = __CASES[SchemaVersion1Dot6]
 
     @classmethod
-    def __normalize(cls, cs: ComponentScope, view: Type[serializable.ViewType]) -> Optional[str]:
+    def __normalize(cls, cs: ComponentScope, view: type[serializable.ViewType]) -> Optional[str]:
         return cs.value \
             if cs in cls.__CASES.get(view, ()) \
             else None
 
     @classmethod
     def json_normalize(cls, o: Any, *,
-                       view: Optional[Type[serializable.ViewType]],
+                       view: Optional[type[serializable.ViewType]],
                        **__: Any) -> Optional[str]:
         assert view is not None
         return cls.__normalize(o, view)
 
     @classmethod
     def xml_normalize(cls, o: Any, *,
-                      view: Optional[Type[serializable.ViewType]],
+                      view: Optional[type[serializable.ViewType]],
                       **__: Any) -> Optional[str]:
         assert view is not None
         return cls.__normalize(o, view)
@@ -354,7 +255,7 @@ class ComponentType(str, Enum):
     Enum object that defines the permissible 'types' for a Component according to the CycloneDX schema.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_classification
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_classification
     """
     # see `_ComponentTypeSerializationHelper.__CASES` for view/case map
     APPLICATION = 'application'
@@ -375,7 +276,7 @@ class ComponentType(str, Enum):
 class _ComponentTypeSerializationHelper(serializable.helpers.BaseHelper):
     """  THIS CLASS IS NON-PUBLIC API  """
 
-    __CASES: Dict[Type[serializable.ViewType], FrozenSet[ComponentType]] = dict()
+    __CASES: dict[type[serializable.ViewType], frozenset[ComponentType]] = dict()
     __CASES[SchemaVersion1Dot0] = frozenset({
         ComponentType.APPLICATION,
         ComponentType.DEVICE,
@@ -401,23 +302,24 @@ class _ComponentTypeSerializationHelper(serializable.helpers.BaseHelper):
     __CASES[SchemaVersion1Dot6] = __CASES[SchemaVersion1Dot5] | {
         ComponentType.CRYPTOGRAPHIC_ASSET,
     }
+    __CASES[SchemaVersion1Dot7] = __CASES[SchemaVersion1Dot6]
 
     @classmethod
-    def __normalize(cls, ct: ComponentType, view: Type[serializable.ViewType]) -> Optional[str]:
+    def __normalize(cls, ct: ComponentType, view: type[serializable.ViewType]) -> Optional[str]:
         if ct in cls.__CASES.get(view, ()):
             return ct.value
         raise SerializationOfUnsupportedComponentTypeException(f'unsupported {ct!r} for view {view!r}')
 
     @classmethod
     def json_normalize(cls, o: Any, *,
-                       view: Optional[Type[serializable.ViewType]],
+                       view: Optional[type[serializable.ViewType]],
                        **__: Any) -> Optional[str]:
         assert view is not None
         return cls.__normalize(o, view)
 
     @classmethod
     def xml_normalize(cls, o: Any, *,
-                      view: Optional[Type[serializable.ViewType]],
+                      view: Optional[type[serializable.ViewType]],
                       **__: Any) -> Optional[str]:
         assert view is not None
         return cls.__normalize(o, view)
@@ -427,13 +329,13 @@ class _ComponentTypeSerializationHelper(serializable.helpers.BaseHelper):
         return ComponentType(o)
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Diff:
     """
     Our internal representation of the `diffType` complex type.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_diffType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_diffType
     """
 
     def __init__(
@@ -501,7 +403,7 @@ class PatchClassification(str, Enum):
     Enum object that defines the permissible `patchClassification`s.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_patchClassification
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_patchClassification
     """
     BACKPORT = 'backport'
     CHERRY_PICK = 'cherry-pick'
@@ -509,13 +411,13 @@ class PatchClassification(str, Enum):
     UNOFFICIAL = 'unofficial'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Patch:
     """
     Our internal representation of the `patchType` complex type.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_patchType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_patchType
     """
 
     def __init__(
@@ -526,7 +428,7 @@ class Patch:
     ) -> None:
         self.type = type
         self.diff = diff
-        self.resolves = resolves or []  # type:ignore[assignment]
+        self.resolves = resolves or []
 
     @property
     @serializable.xml_attribute()
@@ -599,7 +501,7 @@ class Patch:
         return f'<Patch type={self.type}, id={id(self)}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Pedigree:
     """
     Our internal representation of the `pedigreeType` complex type.
@@ -610,7 +512,7 @@ class Pedigree:
     may not be known.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_pedigreeType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_pedigreeType
     """
 
     def __init__(
@@ -622,11 +524,11 @@ class Pedigree:
         patches: Optional[Iterable[Patch]] = None,
         notes: Optional[str] = None,
     ) -> None:
-        self.ancestors = ancestors or []  # type:ignore[assignment]
-        self.descendants = descendants or []  # type:ignore[assignment]
-        self.variants = variants or []  # type:ignore[assignment]
-        self.commits = commits or []  # type:ignore[assignment]
-        self.patches = patches or []  # type:ignore[assignment]
+        self.ancestors = ancestors or []
+        self.descendants = descendants or []
+        self.variants = variants or []
+        self.commits = commits or []
+        self.patches = patches or []
         self.notes = notes
 
     @property
@@ -709,6 +611,7 @@ class Pedigree:
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'patch')
     @serializable.xml_sequence(5)
     def patches(self) -> 'SortedSet[Patch]':
@@ -755,6 +658,11 @@ class Pedigree:
             return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: object) -> bool:
+        if isinstance(other, Pedigree):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.__comparable_tuple())
 
@@ -762,13 +670,13 @@ class Pedigree:
         return f'<Pedigree id={id(self)}, hash={hash(self)}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Swid:
     """
     Our internal representation of the `swidType` complex type.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_swidType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_swidType
     """
 
     def __init__(
@@ -907,6 +815,11 @@ class Swid:
             return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: object) -> bool:
+        if isinstance(other, Swid):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.__comparable_tuple())
 
@@ -914,7 +827,7 @@ class Swid:
         return f'<Swid tagId={self.tag_id}, name={self.name}, version={self.version}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class OmniborId(serializable.helpers.BaseHelper):
     """
     Helper class that allows us to perform validation on data strings that must conform to
@@ -973,7 +886,7 @@ class OmniborId(serializable.helpers.BaseHelper):
         return self._id
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Swhid(serializable.helpers.BaseHelper):
     """
     Helper class that allows us to perform validation on data strings that must conform to
@@ -1032,13 +945,13 @@ class Swhid(serializable.helpers.BaseHelper):
         return self._id
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Component(Dependable):
     """
     This is our internal representation of a Component within a Bom.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_component
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_component
     """
 
     @staticmethod
@@ -1110,38 +1023,32 @@ class Component(Dependable):
         self._bom_ref = _bom_ref_from_str(bom_ref)
         self.supplier = supplier
         self.manufacturer = manufacturer
-        self.authors = authors or []  # type:ignore[assignment]
-        self.author = author
+        self.authors = authors or []
         self.publisher = publisher
         self.group = group
         self.name = name
-        self.version = version
         self.description = description
         self.scope = scope
-        self.hashes = hashes or []  # type:ignore[assignment]
-        self.licenses = licenses or []  # type:ignore[assignment]
+        self.hashes = hashes or []
+        self.licenses = licenses or []
         self.copyright = copyright
         self.cpe = cpe
         self.purl = purl
-        self.omnibor_ids = omnibor_ids or []  # type:ignore[assignment]
-        self.swhids = swhids or []  # type:ignore[assignment]
+        self.omnibor_ids = omnibor_ids or []
+        self.swhids = swhids or []
         self.swid = swid
-        self.modified = modified
         self.pedigree = pedigree
-        self.external_references = external_references or []  # type:ignore[assignment]
-        self.properties = properties or []  # type:ignore[assignment]
-        self.components = components or []  # type:ignore[assignment]
+        self.external_references = external_references or []
+        self.properties = properties or []
+        self.components = components or []
         self.evidence = evidence
         self.release_notes = release_notes
         self.crypto_properties = crypto_properties
-        self.tags = tags or []  # type:ignore[assignment]
-
-        if modified:
-            warn('`.component.modified` is deprecated from CycloneDX v1.3 onwards. '
-                 'Please use `@.pedigree` instead.', DeprecationWarning)
-        if author:
-            warn('`.component.author` is deprecated from CycloneDX v1.6 onwards. '
-                 'Please use `@.authors` or `@.manufacturer` instead.', DeprecationWarning)
+        self.tags = tags or []
+        # spec-deprecated properties below
+        self.author = author
+        self.modified = modified
+        self.version = version
 
     @property
     @serializable.type_mapping(_ComponentTypeSerializationHelper)
@@ -1187,6 +1094,7 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_attribute()
     @serializable.xml_name('bom-ref')
     def bom_ref(self) -> BomRef:
@@ -1205,6 +1113,7 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_sequence(1)
     def supplier(self) -> Optional[OrganizationalEntity]:
         """
@@ -1222,6 +1131,7 @@ class Component(Dependable):
 
     @property
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_sequence(2)
     def manufacturer(self) -> Optional[OrganizationalEntity]:
         """
@@ -1240,6 +1150,7 @@ class Component(Dependable):
 
     @property
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'author')
     @serializable.xml_sequence(3)
     def authors(self) -> 'SortedSet[OrganizationalContact]':
@@ -1262,7 +1173,8 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot3)
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
-    @serializable.view(SchemaVersion1Dot6)  # todo: this is deprecated in v1.6?
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_sequence(4)
     @serializable.xml_string(serializable.XmlStringSerializationType.NORMALIZED_STRING)
     def author(self) -> Optional[str]:
@@ -1276,6 +1188,9 @@ class Component(Dependable):
 
     @author.setter
     def author(self, author: Optional[str]) -> None:
+        if author is not None:
+            warn('`@.author` is deprecated from CycloneDX v1.6 onwards. '
+                 'Please use `@.authors` or `@.manufacturer` instead.', DeprecationWarning)
         self._author = author
 
     @property
@@ -1356,7 +1271,7 @@ class Component(Dependable):
     @version.setter
     def version(self, version: Optional[str]) -> None:
         if version and len(version) > 1024:
-            warn('`.component.version`has a maximum length of 1024 from CycloneDX v1.6 onwards.', UserWarning)
+            warn('`@.version`has a maximum length of 1024 from CycloneDX v1.6 onwards.', UserWarning)
         self._version = version
 
     @property
@@ -1416,6 +1331,7 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.type_mapping(_LicenseRepositorySerializationHelper)
     @serializable.xml_sequence(12)
     def licenses(self) -> LicenseRepository:
@@ -1486,6 +1402,7 @@ class Component(Dependable):
     @property
     @serializable.json_name('omniborId')
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_array(serializable.XmlArraySerializationType.FLAT, child_name='omniborId')
     @serializable.xml_sequence(16)
     def omnibor_ids(self) -> 'SortedSet[OmniborId]':
@@ -1506,6 +1423,7 @@ class Component(Dependable):
     @property
     @serializable.json_name('swhid')
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_array(serializable.XmlArraySerializationType.FLAT, child_name='swhid')
     @serializable.xml_sequence(17)
     def swhids(self) -> 'SortedSet[Swhid]':
@@ -1529,6 +1447,7 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_sequence(18)
     def swid(self) -> Optional[Swid]:
         """
@@ -1551,6 +1470,9 @@ class Component(Dependable):
 
     @modified.setter
     def modified(self, modified: bool) -> None:
+        if modified:
+            warn('`@.modified` is deprecated from CycloneDX v1.3 onwards. '
+                 'Please use `@.pedigree` instead.', DeprecationWarning)
         self._modified = modified
 
     @property
@@ -1560,6 +1482,7 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_sequence(20)
     def pedigree(self) -> Optional[Pedigree]:
         """
@@ -1582,6 +1505,7 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'reference')
     @serializable.xml_sequence(21)
     def external_references(self) -> 'SortedSet[ExternalReference]':
@@ -1603,6 +1527,7 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'property')
     @serializable.xml_sequence(22)
     def properties(self) -> 'SortedSet[Property]':
@@ -1642,7 +1567,9 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_sequence(24)
+    @serializable.type_mapping(_ComponentEvidenceSerializationHelper)
     def evidence(self) -> Optional[ComponentEvidence]:
         """
         Provides the ability to document evidence collected through various forms of extraction or analysis.
@@ -1660,6 +1587,7 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_sequence(25)
     def release_notes(self) -> Optional[ReleaseNotes]:
         """
@@ -1698,6 +1626,7 @@ class Component(Dependable):
 
     @property
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_sequence(30)
     def crypto_properties(self) -> Optional[CryptoProperties]:
         """
@@ -1718,6 +1647,7 @@ class Component(Dependable):
 
     @property
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'tag')
     @serializable.xml_sequence(31)
     def tags(self) -> 'SortedSet[str]':
@@ -1734,7 +1664,7 @@ class Component(Dependable):
     def tags(self, tags: Iterable[str]) -> None:
         self._tags = SortedSet(tags)
 
-    def get_all_nested_components(self, include_self: bool = False) -> Set['Component']:
+    def get_all_nested_components(self, include_self: bool = False) -> set['Component']:
         components = set()
         if include_self:
             components.add(self)
