@@ -22,18 +22,20 @@ License related things
 
 from enum import Enum
 from json import loads as json_loads
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, Union
+from typing import TYPE_CHECKING, Any, Optional, Union
 from warnings import warn
 from xml.etree.ElementTree import Element  # nosec B405
 
 import py_serializable as serializable
 from sortedcontainers import SortedSet
 
+from .._internal.bom_ref import bom_ref_from_str as _bom_ref_from_str
 from .._internal.compare import ComparableTuple as _ComparableTuple
 from ..exception.model import MutuallyExclusivePropertiesException
 from ..exception.serialization import CycloneDxDeserializationException
-from ..schema.schema import SchemaVersion1Dot6
+from ..schema.schema import SchemaVersion1Dot5, SchemaVersion1Dot6, SchemaVersion1Dot7
 from . import AttachedText, XsUri
+from .bom_ref import BomRef
 
 
 @serializable.serializable_enum
@@ -47,7 +49,7 @@ class LicenseAcknowledgement(str, Enum):
 
     .. note::
         See the CycloneDX Schema for hashType:
-        https://cyclonedx.org/docs/1.6/#type_licenseAcknowledgementEnumerationType
+        https://cyclonedx.org/docs/1.7/xml/#type_licenseAcknowledgementEnumerationType
     """
 
     CONCLUDED = 'concluded'
@@ -60,18 +62,22 @@ LicenseExpressionAcknowledgement = LicenseAcknowledgement
 """Deprecated alias for :class:`LicenseAcknowledgement`"""
 
 
-@serializable.serializable_class(name='license')
+@serializable.serializable_class(
+    name='license',
+    ignore_unknown_during_deserialization=True
+)
 class DisjunctiveLicense:
     """
     This is our internal representation of `licenseType` complex type that can be used in multiple places within
     a CycloneDX BOM document.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/json/#components_items_licenses
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_licenseType
     """
 
     def __init__(
         self, *,
+        bom_ref: Optional[Union[str, BomRef]] = None,
         id: Optional[str] = None, name: Optional[str] = None,
         text: Optional[AttachedText] = None, url: Optional[XsUri] = None,
         acknowledgement: Optional[LicenseAcknowledgement] = None,
@@ -83,12 +89,31 @@ class DisjunctiveLicense:
                 'Both `id` and `name` have been supplied - `name` will be ignored!',
                 category=RuntimeWarning, stacklevel=1
             )
+        self._bom_ref = _bom_ref_from_str(bom_ref)
         self._id = id
         self._name = name if not id else None
         self._text = text
         self._url = url
         self._acknowledgement = acknowledgement
 
+    @property
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
+    @serializable.type_mapping(BomRef)
+    @serializable.xml_attribute()
+    @serializable.xml_name('bom-ref')
+    @serializable.json_name('bom-ref')
+    def bom_ref(self) -> BomRef:
+        """
+        An optional identifier which can be used to reference the component elsewhere in the BOM. Every bom-ref MUST be
+        unique within the BOM.
+
+        Returns:
+            `BomRef`
+        """
+        return self._bom_ref
+
     @property
     @serializable.xml_sequence(1)
     def id(self) -> Optional[str]:
@@ -97,7 +122,7 @@ class DisjunctiveLicense:
 
         .. note::
           See the list of expected values:
-          https://cyclonedx.org/docs/1.6/json/#components_items_licenses_items_license_id
+          https://cyclonedx.org/docs/1.7/json/#components_items_licenses_items_license_id
 
         Returns:
             `str` or `None`
@@ -183,18 +208,9 @@ class DisjunctiveLicense:
     # def properties(self, ...) -> None:
     #     ...  # TODO since CDX1.5
 
-    # @property
-    # @serializable.json_name('bom-ref')
-    # @serializable.type_mapping(BomRefHelper)
-    # @serializable.view(SchemaVersion1Dot5)
-    # @serializable.view(SchemaVersion1Dot6)
-    # @serializable.xml_attribute()
-    # @serializable.xml_name('bom-ref')
-    # def bom_ref(self) -> BomRef:
-    #     ...  # TODO since CDX1.5
-
     @property
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_attribute()
     def acknowledgement(self) -> Optional[LicenseAcknowledgement]:
         """
@@ -224,6 +240,7 @@ class DisjunctiveLicense:
             self._id, self._name,
             self._url,
             self._text,
+            self._bom_ref.value,
         ))
 
     def __eq__(self, other: object) -> bool:
@@ -245,7 +262,10 @@ class DisjunctiveLicense:
         return f'<License id={self._id!r}, name={self._name!r}>'
 
 
-@serializable.serializable_class(name='expression')
+@serializable.serializable_class(
+    name='expression',
+    ignore_unknown_during_deserialization=True
+)
 class LicenseExpression:
     """
     This is our internal representation of `licenseType`'s  expression type that can be used in multiple places within
@@ -253,16 +273,36 @@ class LicenseExpression:
 
     .. note::
         See the CycloneDX Schema definition:
-        https://cyclonedx.org/docs/1.6/json/#components_items_licenses_items_expression
+        https://cyclonedx.org/docs/1.7/json/#components_items_licenses_items_expression
     """
 
     def __init__(
         self, value: str, *,
+        bom_ref: Optional[Union[str, BomRef]] = None,
         acknowledgement: Optional[LicenseAcknowledgement] = None,
     ) -> None:
+        self._bom_ref = _bom_ref_from_str(bom_ref)
         self._value = value
         self._acknowledgement = acknowledgement
 
+    @property
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
+    @serializable.type_mapping(BomRef)
+    @serializable.xml_attribute()
+    @serializable.xml_name('bom-ref')
+    @serializable.json_name('bom-ref')
+    def bom_ref(self) -> BomRef:
+        """
+        An optional identifier which can be used to reference the component elsewhere in the BOM. Every bom-ref MUST be
+        unique within the BOM.
+
+        Returns:
+            `BomRef`
+        """
+        return self._bom_ref
+
     @property
     @serializable.xml_name('.')
     @serializable.xml_string(serializable.XmlStringSerializationType.NORMALIZED_STRING)
@@ -280,18 +320,9 @@ class LicenseExpression:
     def value(self, value: str) -> None:
         self._value = value
 
-    # @property
-    # @serializable.json_name('bom-ref')
-    # @serializable.type_mapping(BomRefHelper)
-    # @serializable.view(SchemaVersion1Dot5)
-    # @serializable.view(SchemaVersion1Dot6)
-    # @serializable.xml_attribute()
-    # @serializable.xml_name('bom-ref')
-    # def bom_ref(self) -> BomRef:
-    #     ...  # TODO since CDX1.5
-
     @property
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_attribute()
     def acknowledgement(self) -> Optional[LicenseAcknowledgement]:
         """
@@ -319,6 +350,7 @@ class LicenseExpression:
         return _ComparableTuple((
             self._acknowledgement,
             self._value,
+            self._bom_ref.value,
         ))
 
     def __hash__(self) -> int:
@@ -385,7 +417,7 @@ class _LicenseRepositorySerializationHelper(serializable.helpers.BaseHelper):
 
     @classmethod
     def json_normalize(cls, o: LicenseRepository, *,
-                       view: Optional[Type[serializable.ViewType]],
+                       view: Optional[type[serializable.ViewType]],
                        **__: Any) -> Any:
         if len(o) == 0:
             return None
@@ -405,7 +437,7 @@ class _LicenseRepositorySerializationHelper(serializable.helpers.BaseHelper):
         ]
 
     @classmethod
-    def json_denormalize(cls, o: List[Dict[str, Any]],
+    def json_denormalize(cls, o: list[dict[str, Any]],
                          **__: Any) -> LicenseRepository:
         repo = LicenseRepository()
         for li in o:
@@ -423,7 +455,7 @@ class _LicenseRepositorySerializationHelper(serializable.helpers.BaseHelper):
     @classmethod
     def xml_normalize(cls, o: LicenseRepository, *,
                       element_name: str,
-                      view: Optional[Type[serializable.ViewType]],
+                      view: Optional[type[serializable.ViewType]],
                       xmlns: Optional[str],
                       **__: Any) -> Optional[Element]:
         if len(o) == 0:
