@@ -20,18 +20,25 @@
 This set of classes represents the data that is possible about known Services.
 
 .. note::
-    See the CycloneDX Schema extension definition https://cyclonedx.org/docs/1.6/xml/#type_servicesType
+    See the CycloneDX Schema extension definition https://cyclonedx.org/docs/1.7/xml/#type_servicesType
 """
 
 
-from typing import Any, Iterable, Optional, Union
+from collections.abc import Iterable
+from typing import Any, Optional, Union
 
 import py_serializable as serializable
 from sortedcontainers import SortedSet
 
 from .._internal.bom_ref import bom_ref_from_str as _bom_ref_from_str
 from .._internal.compare import ComparableTuple as _ComparableTuple
-from ..schema.schema import SchemaVersion1Dot3, SchemaVersion1Dot4, SchemaVersion1Dot5, SchemaVersion1Dot6
+from ..schema.schema import (
+    SchemaVersion1Dot3,
+    SchemaVersion1Dot4,
+    SchemaVersion1Dot5,
+    SchemaVersion1Dot6,
+    SchemaVersion1Dot7,
+)
 from . import DataClassification, ExternalReference, Property, XsUri
 from .bom_ref import BomRef
 from .contact import OrganizationalEntity
@@ -40,13 +47,13 @@ from .license import License, LicenseRepository, _LicenseRepositorySerialization
 from .release_note import ReleaseNotes
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Service(Dependable):
     """
     Class that models the `service` complex type in the CycloneDX schema.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_service
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.7/xml/#type_service
     """
 
     def __init__(
@@ -73,15 +80,15 @@ class Service(Dependable):
         self.name = name
         self.version = version
         self.description = description
-        self.endpoints = endpoints or []  # type:ignore[assignment]
+        self.endpoints = endpoints or []
         self.authenticated = authenticated
         self.x_trust_boundary = x_trust_boundary
-        self.data = data or []  # type:ignore[assignment]
-        self.licenses = licenses or []  # type:ignore[assignment]
-        self.external_references = external_references or []  # type:ignore[assignment]
-        self.services = services or []  # type:ignore[assignment]
+        self.data = data or []
+        self.licenses = licenses or []
+        self.external_references = external_references or []
+        self.services = services or []
         self.release_notes = release_notes
-        self.properties = properties or []  # type:ignore[assignment]
+        self.properties = properties or []
 
     @property
     @serializable.json_name('bom-ref')
@@ -298,6 +305,7 @@ class Service(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'property')
     @serializable.xml_sequence(13)
     def properties(self) -> 'SortedSet[Property]':
@@ -338,6 +346,7 @@ class Service(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_sequence(15)
     def release_notes(self) -> Optional[ReleaseNotes]:
         """
