@@ -25,15 +25,16 @@ a schema extension: https://cyclonedx.org/ext/vulnerability.
 Since CycloneDX schema version 1.4, this has become part of the core schema.
 
 .. note::
-    See the CycloneDX Schema extension definition https://cyclonedx.org/docs/1.6/#type_vulnerabilitiesType
+    See the CycloneDX Schema extension definition https://cyclonedx.org/docs/1.7/xml/#type_vulnerabilitiesType
 """
 
 
 import re
+from collections.abc import Iterable
 from datetime import datetime
 from decimal import Decimal
 from enum import Enum
-from typing import Any, Dict, FrozenSet, Iterable, Optional, Tuple, Type, Union
+from typing import Any, Optional, Union
 
 import py_serializable as serializable
 from sortedcontainers import SortedSet
@@ -41,7 +42,7 @@ from sortedcontainers import SortedSet
 from .._internal.bom_ref import bom_ref_from_str as _bom_ref_from_str
 from .._internal.compare import ComparableTuple as _ComparableTuple
 from ..exception.model import MutuallyExclusivePropertiesException, NoPropertiesProvidedException
-from ..schema.schema import SchemaVersion1Dot4, SchemaVersion1Dot5, SchemaVersion1Dot6
+from ..schema.schema import SchemaVersion1Dot4, SchemaVersion1Dot5, SchemaVersion1Dot6, SchemaVersion1Dot7
 from . import Property, XsUri
 from .bom_ref import BomRef
 from .contact import OrganizationalContact, OrganizationalEntity
@@ -54,7 +55,7 @@ from .impact_analysis import (
 from .tool import Tool, ToolRepository, _ToolRepositoryHelper
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class BomTargetVersionRange:
     """
     Class that represents either a version or version range and its affected status.
@@ -62,7 +63,8 @@ class BomTargetVersionRange:
     `version` and `version_range` are mutually exclusive.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilityType
+        See the CycloneDX schema:
+        https://cyclonedx.org/docs/1.7/json/#tab-pane_vulnerabilities_items_affects_items_versions_items_oneOf_i0
     """
 
     def __init__(
@@ -147,7 +149,7 @@ class BomTargetVersionRange:
         return f'<BomTargetVersionRange version={self.version}, version_range={self.range}, status={self.status}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class BomTarget:
     """
     Class that represents referencing a Component or Service in a BOM.
@@ -158,7 +160,7 @@ class BomTarget:
     from a `cyclonedx.parser.BaseParser` implementation.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/#type_vulnerabilityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.7/json/#vulnerabilities_items_affects
     """
 
     def __init__(
@@ -167,7 +169,7 @@ class BomTarget:
         versions: Optional[Iterable[BomTargetVersionRange]] = None,
     ) -> None:
         self.ref = ref
-        self.versions = versions or []  # type:ignore[assignment]
+        self.versions = versions or []
 
     @property
     @serializable.xml_sequence(1)
@@ -220,13 +222,13 @@ class BomTarget:
         return f'<BomTarget ref={self.ref}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilityAnalysis:
     """
     Class that models the `analysis` sub-element of the `vulnerabilityType` complex type.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.7/json/#vulnerabilities_items_analysis
     """
 
     def __init__(
@@ -240,7 +242,7 @@ class VulnerabilityAnalysis:
     ) -> None:
         self.state = state
         self.justification = justification
-        self.responses = responses or []  # type:ignore[assignment]
+        self.responses = responses or []
         self.detail = detail
         self.first_issued = first_issued
         self.last_updated = last_updated
@@ -314,6 +316,7 @@ class VulnerabilityAnalysis:
     @property
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.type_mapping(serializable.helpers.XsdDateTime)
     @serializable.xml_sequence(5)
     def first_issued(self) -> Optional[datetime]:
@@ -326,6 +329,7 @@ class VulnerabilityAnalysis:
     @property
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.type_mapping(serializable.helpers.XsdDateTime)
     @serializable.xml_sequence(6)
     def last_updated(self) -> Optional[datetime]:
@@ -348,6 +352,11 @@ class VulnerabilityAnalysis:
             return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: Any) -> bool:
+        if isinstance(other, VulnerabilityAnalysis):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.__comparable_tuple())
 
@@ -355,13 +364,13 @@ class VulnerabilityAnalysis:
         return f'<VulnerabilityAnalysis state={self.state}, justification={self.justification}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilityAdvisory:
     """
     Class that models the `advisoryType` complex type.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/#type_advisoryType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.7/json/#vulnerabilities_items_advisories
     """
 
     def __init__(
@@ -419,7 +428,7 @@ class VulnerabilityAdvisory:
         return f'<VulnerabilityAdvisory url={self.url}, title={self.title}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilitySource:
     """
     Class that models the `vulnerabilitySourceType` complex type.
@@ -427,7 +436,7 @@ class VulnerabilitySource:
     This type is used for multiple purposes in the CycloneDX schema.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilitySourceType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.7/json/#vulnerabilities_items_source
     """
 
     def __init__(
@@ -485,7 +494,7 @@ class VulnerabilitySource:
         return f'<VulnerabilityAdvisory name={self.name}, url={self.url}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilityReference:
     """
     Class that models the nested `reference` within the `vulnerabilityType` complex type.
@@ -496,7 +505,7 @@ class VulnerabilityReference:
     intelligence.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.7/json/#vulnerabilities_items_references
 
     .. note::
         Properties ``id`` and ``source`` are mandatory.
@@ -576,12 +585,13 @@ class VulnerabilityScoreSource(str, Enum):
     Enum object that defines the permissible source types for a Vulnerability's score.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_scoreSourceType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_scoreSourceType
 
     .. note::
         No explicit carry-over from the former schema extension:
          https://github.com/CycloneDX/specification/blob/master/schema/ext/vulnerability-1.0.xsd
     """
+
     # see `_VulnerabilityScoreSourceSerializationHelper.__CASES` for view/case map
     CVSS_V2 = 'CVSSv2'
     CVSS_V3 = 'CVSSv3'
@@ -605,14 +615,17 @@ class VulnerabilityScoreSource(str, Enum):
             Always returns an instance of `VulnerabilityScoreSource`. `VulnerabilityScoreSource.OTHER` is
             returned if the scheme is not obvious or known to us.
         """
+        if vector.startswith('CVSS:4.'):
+            return VulnerabilityScoreSource.CVSS_V4
         if vector.startswith('CVSS:3.'):
+            if vector.startswith('CVSS:3.1'):
+                return VulnerabilityScoreSource.CVSS_V3_1
             return VulnerabilityScoreSource.CVSS_V3
-        elif vector.startswith('CVSS:2.'):
+        if vector.startswith('CVSS:2.'):
             return VulnerabilityScoreSource.CVSS_V2
-        elif vector.startswith('OWASP'):
+        if vector.startswith('OWASP'):
             return VulnerabilityScoreSource.OWASP
-        else:
-            return VulnerabilityScoreSource.OTHER
+        return VulnerabilityScoreSource.OTHER
 
     def get_localised_vector(self, vector: str) -> str:
         """
@@ -624,15 +637,16 @@ class VulnerabilityScoreSource(str, Enum):
         Returns:
             The vector without any scheme prefix as a `str`.
         """
-        if self == VulnerabilityScoreSource.CVSS_V3 and vector.startswith('CVSS:3.'):
-            return re.sub('^CVSS:3\\.\\d/?', '', vector)
-
-        if self == VulnerabilityScoreSource.CVSS_V2 and vector.startswith('CVSS:2.'):
-            return re.sub('^CVSS:2\\.\\d/?', '', vector)
-
-        if self == VulnerabilityScoreSource.OWASP and vector.startswith('OWASP'):
-            return re.sub('^OWASP/?', '', vector)
-
+        if self is VulnerabilityScoreSource.CVSS_V4 and vector.startswith('CVSS:4.'):
+            return re.sub(r'^CVSS:4\.\d/?', '', vector)
+        if (
+            self in (VulnerabilityScoreSource.CVSS_V3_1, VulnerabilityScoreSource.CVSS_V3)
+        ) and vector.startswith('CVSS:3.'):
+            return re.sub(r'^CVSS:3\.\d/?', '', vector)
+        if self is VulnerabilityScoreSource.CVSS_V2 and vector.startswith('CVSS:2.'):
+            return re.sub(r'^CVSS:2\.\d/?', '', vector)
+        if self is VulnerabilityScoreSource.OWASP and vector.startswith('OWASP'):
+            return re.sub(r'^OWASP/?', '', vector)
         return vector
 
     def get_value_pre_1_4(self) -> str:
@@ -643,7 +657,7 @@ class VulnerabilityScoreSource(str, Enum):
         Returns:
             `str`
         """
-        if self == VulnerabilityScoreSource.OWASP:
+        if self is VulnerabilityScoreSource.OWASP:
             return 'OWASP Risk'
         return self.value  # type:ignore[no-any-return]
 
@@ -651,7 +665,7 @@ class VulnerabilityScoreSource(str, Enum):
 class _VulnerabilityScoreSourceSerializationHelper(serializable.helpers.BaseHelper):
     """  THIS CLASS IS NON-PUBLIC API  """
 
-    __CASES: Dict[Type[serializable.ViewType], FrozenSet[VulnerabilityScoreSource]] = dict()
+    __CASES: dict[type[serializable.ViewType], frozenset[VulnerabilityScoreSource]] = dict()
     __CASES[SchemaVersion1Dot4] = frozenset({
         VulnerabilityScoreSource.CVSS_V2,
         VulnerabilityScoreSource.CVSS_V3,
@@ -664,9 +678,10 @@ class _VulnerabilityScoreSourceSerializationHelper(serializable.helpers.BaseHelp
         VulnerabilityScoreSource.SSVC
     }
     __CASES[SchemaVersion1Dot6] = __CASES[SchemaVersion1Dot5]
+    __CASES[SchemaVersion1Dot7] = __CASES[SchemaVersion1Dot6]
 
     @classmethod
-    def __normalize(cls, vss: VulnerabilityScoreSource, view: Type[serializable.ViewType]) -> str:
+    def __normalize(cls, vss: VulnerabilityScoreSource, view: type[serializable.ViewType]) -> str:
         return (
             vss
             if vss in cls.__CASES.get(view, ())
@@ -675,14 +690,14 @@ class _VulnerabilityScoreSourceSerializationHelper(serializable.helpers.BaseHelp
 
     @classmethod
     def json_normalize(cls, o: Any, *,
-                       view: Optional[Type[serializable.ViewType]],
+                       view: Optional[type[serializable.ViewType]],
                        **__: Any) -> str:
         assert view is not None
         return cls.__normalize(o, view)
 
     @classmethod
     def xml_normalize(cls, o: Any, *,
-                      view: Optional[Type[serializable.ViewType]],
+                      view: Optional[type[serializable.ViewType]],
                       **__: Any) -> str:
         assert view is not None
         return cls.__normalize(o, view)
@@ -698,7 +713,7 @@ class VulnerabilitySeverity(str, Enum):
     Class that defines the permissible severities for a Vulnerability.
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/#type_severityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.7/xml/#type_severityType
     """
     NONE = 'none'
     INFO = 'info'  # Only >= 1.4
@@ -709,7 +724,7 @@ class VulnerabilitySeverity(str, Enum):
     UNKNOWN = 'unknown'
 
     @staticmethod
-    def get_from_cvss_scores(scores: Union[Tuple[float, ...], float, None]) -> 'VulnerabilitySeverity':
+    def get_from_cvss_scores(scores: Union[tuple[float, ...], float, None]) -> 'VulnerabilitySeverity':
         """
         Derives the Severity of a Vulnerability from it's declared CVSS scores.
 
@@ -743,7 +758,7 @@ class VulnerabilitySeverity(str, Enum):
             return VulnerabilitySeverity.NONE
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilityRating:
     """
     Class that models the `ratingType` complex element CycloneDX core schema.
@@ -752,7 +767,7 @@ class VulnerabilityRating:
     1.4 - see https://github.com/CycloneDX/specification/blob/master/schema/ext/vulnerability-1.0.xsd.
 
     .. note::
-        See `ratingType` in https://cyclonedx.org/docs/1.6/xml/#ratingType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_ratingType
 
     .. warning::
         As part of implementing support for CycloneDX schema version 1.4, the three score types defined in the schema
@@ -881,7 +896,7 @@ class VulnerabilityRating:
             f'justification={self.justification}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class VulnerabilityCredits:
     """
     Class that models the `credits` of `vulnerabilityType` complex type in the CycloneDX schema (version >= 1.4).
@@ -890,7 +905,7 @@ class VulnerabilityCredits:
     extension (in XML only).
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/xml/#type_vulnerabilityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.7/json/#vulnerabilities_items_credits
     """
 
     def __init__(
@@ -898,8 +913,8 @@ class VulnerabilityCredits:
         organizations: Optional[Iterable[OrganizationalEntity]] = None,
         individuals: Optional[Iterable[OrganizationalContact]] = None,
     ) -> None:
-        self.organizations = organizations or []  # type:ignore[assignment]
-        self.individuals = individuals or []  # type:ignore[assignment]
+        self.organizations = organizations or []
+        self.individuals = individuals or []
 
     @property
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'organization')
@@ -956,7 +971,7 @@ class VulnerabilityCredits:
         return f'<VulnerabilityCredits id={id(self)}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Vulnerability:
     """
     Class that models the `vulnerabilityType` complex type in the CycloneDX schema (version >= 1.4).
@@ -965,7 +980,7 @@ class Vulnerability:
     extension (in XML only).
 
     .. note::
-        See the CycloneDX schema: https://cyclonedx.org/docs/1.6/#type_vulnerabilityType
+        See the CycloneDX schema: https://cyclonedx.org/docs/1.7/xml/#type_vulnerabilityType
     """
 
     def __init__(
@@ -993,22 +1008,22 @@ class Vulnerability:
         self._bom_ref = _bom_ref_from_str(bom_ref)
         self.id = id
         self.source = source
-        self.references = references or []  # type:ignore[assignment]
-        self.ratings = ratings or []  # type:ignore[assignment]
-        self.cwes = cwes or []  # type:ignore[assignment]
+        self.references = references or []
+        self.ratings = ratings or []
+        self.cwes = cwes or []
         self.description = description
         self.detail = detail
         self.recommendation = recommendation
         self.workaround = workaround
-        self.advisories = advisories or []  # type:ignore[assignment]
+        self.advisories = advisories or []
         self.created = created
         self.published = published
         self.updated = updated
         self.credits = credits
-        self.tools = tools or []  # type:ignore[assignment]
+        self.tools = tools or []
         self.analysis = analysis
-        self.affects = affects or []  # type:ignore[assignment]
-        self.properties = properties or []  # type:ignore[assignment]
+        self.affects = affects or []
+        self.properties = properties or []
 
     @property
     @serializable.json_name('bom-ref')
@@ -1158,6 +1173,7 @@ class Vulnerability:
     @property
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
+    @serializable.view(SchemaVersion1Dot7)
     @serializable.xml_sequence(9)
     def workaround(self) -> Optional[str]:
         """
