@@ -16,10 +16,11 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 
+from collections.abc import Generator, Iterable
 from enum import Enum
 from itertools import chain
 from json import load as json_load
-from typing import Any, Generator, Iterable, Tuple, Type
+from typing import Any
 from unittest import TestCase
 from warnings import warn
 from xml.etree.ElementTree import parse as xml_parse  # nosec B405
@@ -29,7 +30,7 @@ from ddt import ddt, idata, named_data
 from cyclonedx.exception import MissingOptionalDependencyException
 from cyclonedx.exception.serialization import SerializationOfUnsupportedComponentTypeException
 from cyclonedx.model import AttachedText, ExternalReference, HashType, XsUri
-from cyclonedx.model.bom import Bom, BomMetaData
+from cyclonedx.model.bom import Bom, BomMetaData, DistributionConstraints, TlpClassification
 from cyclonedx.model.component import Component, Patch, Pedigree
 from cyclonedx.model.issue import IssueType
 from cyclonedx.model.license import DisjunctiveLicense
@@ -102,8 +103,7 @@ def dp_cases_from_json_schema(sf: str, jsonpointer: Iterable[str]) -> Generator[
             data = data[pp]
     except KeyError:
         return
-    for value in data['enum']:
-        yield value
+    yield from data['enum']
 
 
 def dp_cases_from_json_schemas(*jsonpointer: str) -> Generator[str, None, None]:
@@ -128,7 +128,7 @@ NAMED_OF_SV = tuple(
 
 class _EnumTestCase(TestCase, SnapshotMixin):
 
-    def _test_knows_value(self, enum: Type[Enum], value: str) -> None:
+    def _test_knows_value(self, enum: type[Enum], value: str) -> None:
         ec = enum(value)  # throws valueError if value unknown
         self.assertTrue(ec.name)  # TODO test for an expected name
 
@@ -258,7 +258,7 @@ class _DP_ComponentType():  # noqa: N801
     JSON_SCHEMA_POINTER = ('definitions', 'component', 'properties', 'type')
 
     @classmethod
-    def unsupported_cases(cls) -> Generator[Tuple[str, OutputFormat, SchemaVersion, ComponentType], None, None]:
+    def unsupported_cases(cls) -> Generator[tuple[str, OutputFormat, SchemaVersion, ComponentType], None, None]:
         for name, of, sv in NAMED_OF_SV:
             if OutputFormat.XML is of:
                 schema_cases = set(dp_cases_from_xml_schema(SCHEMA_XML[sv], cls.XML_SCHEMA_XPATH))
@@ -490,3 +490,21 @@ class TestEnumLifecyclePhase(_EnumTestCase):
             lifecycles=[PredefinedLifecycle(phase=phase) for phase in LifecyclePhase]
         ))
         super()._test_cases_render(bom, of, sv)
+
+
+@ddt
+class TestEnumTlpClassification(_EnumTestCase):
+
+    @idata(set(chain(
+        dp_cases_from_xml_schemas(f"./{SCHEMA_NS}simpleType[@name='tlpClassificationType']"),
+        dp_cases_from_json_schemas('definitions', 'tlpClassification'),
+    )))
+    def test_knows_value(self, value: str) -> None:
+        super()._test_knows_value(TlpClassification, value)
+
+    @named_data(*NAMED_OF_SV)
+    def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
+        bom = _make_bom(metadata=BomMetaData(
+            distribution_constraints=DistributionConstraints(tlp=TlpClassification.CLEAR)
+        ))
+        super()._test_cases_render(bom, of, sv)
