@@ -15,8 +15,8 @@
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
+from collections.abc import Generator
 from os.path import isfile
-from typing import Generator
 from unittest import TestCase
 
 from ddt import ddt, idata
@@ -31,6 +31,7 @@ def _dp_files() -> Generator:
                 yield file
     yield _res.SPDX_JSON
     yield _res.SPDX_XML
+    yield _res.CRYPTOGRAPHY_DEFS
     yield _res.JSF
 
 
